==============
 Introduction
==============

dipy_ is in development mode at the moment. 

Please do join in the fun.

The lead developer is Eleftherios Garyfallidis, with support from Ian
Nimmo-Smith, Matthew Brett, Bago Amirbekian, Frank Yeh, Christopher Nguyen and (your name here). See the main documentation for the full list of dipy developers and contributors.

The primary develpoment repository is `dipy github`_ 

Please do contribute.  Have a look at :ref:`using-git` for some ideas on
how to get going.

Have a look at the `nipy development guidelines`_ for our coding habits.
In summary, please follow the `numpy coding style`_ - and of course -
PEP8_ .  Test everything!  We are using nose_ ; see the existing code
for example tests.  If you can please use our :ref:`commit-codes`.

But - just pitch in - send us some code - we'll give you feedback if you
want it - that way we learn from each other.

And - welcome...


